Report

Go to page content

# Dexy Run Report

## Results of your Run

This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.

### Timing

The total elapsed time for batch 1002 was 0.46 (0.01 minutes).

### Config

This is the configuration which was used for this run:

    Directory .:
    code:
        - .R|rout

    .md|jinja|pandoc:
        - pandoc: { args: '--toc' }
        - code

    .md|jinja|pandoc|-odt:
        - pandoc: { ext : .odt }
        - code

    .md|jinja|pandoc|-pdf:
        - pandoc: { ext : .pdf }
        - code

    .md|jinja|pandoc|-docx:
        - pandoc: { ext : .docx, args: '--toc' }
        - code

# 10 Slowest Tasks

- 0.007 - example.R|rout (cached)
- 0.001 - report.md|jinja|pandoc|-pdf (cached)
- 0.000 - report.md|jinja (cached)
- 0.000 - report.md|jinja|pandoc (cached)
- 0.000 - report.md|jinja|pandoc|-odt (cached)
- 0.000 - report.md|jinja|pandoc|-docx (cached)
- 0.000 - example.R ()
- 0.000 - storage.json ()
- 0.000 - plot.png ()
- 0.000 - example.txt ()

# Documents

## example.R|rout ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
example.R | artifacts/37efdae66ef5056d41883121456b3c86.R | 0.0001 |  |
example.R|rout | artifacts/16229d63a9449308b5f2f45013c9b2ab.txt | 0.0067 | cached |

#### Document Log

    2012-11-19 13:28:50,367 - example.R|rout - DEBUG - Setting up FilterArtifact:example.R|rout
    2012-11-19 13:28:50,396 - example.R|rout - DEBUG - Setting hashstring for example.R|rout to 16229d63a9449308b5f2f45013c9b2ab
    2012-11-19 13:28:50,397 - example.R|rout - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,504 - example.R|rout - DEBUG - Running FilterArtifact:example.R|rout
    2012-11-19 13:28:50,504 - example.R|rout - DEBUG - Output is cached under 16229d63a9449308b5f2f45013c9b2ab, reconstituting...
    2012-11-19 13:28:50,506 - example.R|rout - DEBUG - Reconstituting example.txt from database and cache
    2012-11-19 13:28:50,507 - example.R|rout - DEBUG - adding additional doc example.txt (created by example.R|rout)
    2012-11-19 13:28:50,508 - example.R|rout - DEBUG - Reconstituting example.txt from database and cache
    2012-11-19 13:28:50,508 - example.R|rout - DEBUG - Reconstituting plot.png from database and cache
    2012-11-19 13:28:50,508 - example.R|rout - DEBUG - adding additional doc plot.png (created by example.R|rout)
    2012-11-19 13:28:50,509 - example.R|rout - DEBUG - Reconstituting plot.png from database and cache
    2012-11-19 13:28:50,509 - example.R|rout - DEBUG - Reconstituting storage.json from database and cache
    2012-11-19 13:28:50,509 - example.R|rout - DEBUG - adding additional doc storage.json (created by example.R|rout)
    2012-11-19 13:28:50,510 - example.R|rout - DEBUG - Reconstituting storage.json from database and cache

## report.md|jinja|pandoc|-odt ↑

#### Arguments

    pandoc:
        ext: .odt

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |
report.md|jinja | artifacts/2a72b42ef21c8c1f4e0febeec01055a0.md | 0.0006 | cached |
report.md|jinja|pandoc | artifacts/29996ad27404cf4801ddb34257031d71.odt | 0.0006 | cached |
report.md|jinja|pandoc|-odt | artifacts/967edcbaf43c70b71d5aba20b1173d6f.odt | 0.0003 | cached |

#### Document Log

    2012-11-19 13:28:50,408 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,411 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:50,411 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,411 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,424 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc|-odt - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-odt
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc|-odt - DEBUG - Setting hashstring for report.md|jinja|pandoc|-odt to 967edcbaf43c70b71d5aba20b1173d6f
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc|-odt - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,426 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,427 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 5827f92eeba9814fbb4d56feb048b948
    2012-11-19 13:28:50,428 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,429 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,444 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d72203e81399796ef0d7108e22f89626
    2012-11-19 13:28:50,446 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,449 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,451 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:50,452 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,453 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,476 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,478 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:50,479 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,480 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,496 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:50,498 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,511 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,512 - report.md|jinja - DEBUG - Output is cached under 2a72b42ef21c8c1f4e0febeec01055a0, reconstituting...
    2012-11-19 13:28:50,512 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,513 - report.md|jinja|pandoc - DEBUG - Output is cached under 29996ad27404cf4801ddb34257031d71, reconstituting...
    2012-11-19 13:28:50,513 - report.md|jinja|pandoc|-odt - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-odt
    2012-11-19 13:28:50,513 - report.md|jinja|pandoc|-odt - DEBUG - Output is cached under 967edcbaf43c70b71d5aba20b1173d6f, reconstituting...
    2012-11-19 13:28:50,514 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,514 - report.md|jinja - DEBUG - Output is not cached under 5827f92eeba9814fbb4d56feb048b948, running...
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/5827f92eeba9814fbb4d56feb048b948/, artifacts/5827f92eeba9814fbb4d56feb048b948
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:50,545 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:50,545 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', u'/example.txt', u'/plot.png', u'/storage.json', 'example.R-rout.txt', 'example.R|rout', u'example.txt', u'plot.png', u'storage.json']
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:50,547 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:50,550 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Output is not cached under d72203e81399796ef0d7108e22f89626, running...
    2012-11-19 13:28:50,553 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.html' in 'artifacts/d72203e81399796ef0d7108e22f89626/'
    2012-11-19 13:28:50,603 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:50,604 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:50,609 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,610 - report.md|jinja - DEBUG - Output is cached under 999ed730dae84c7227d1fd380e280f57, reconstituting...
    2012-11-19 13:28:50,612 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,613 - report.md|jinja|pandoc - DEBUG - Output is cached under 374dafaaec8b9be60e3a3b94ce9df20c, reconstituting...
    2012-11-19 13:28:50,615 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,616 - report.md|jinja - DEBUG - Output is cached under 679cc4370ea3018f8d90b3a36b8dc579, reconstituting...
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Output is cached under c92599097f2fed1fc118e48ed95e0bd0, reconstituting...

## report.md|jinja|pandoc ↑

#### Arguments

    pandoc:
        args: --toc

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |
report.md|jinja | artifacts/5827f92eeba9814fbb4d56feb048b948.md | 0.0370 | generated |
report.md|jinja|pandoc | artifacts/d72203e81399796ef0d7108e22f89626.html | 0.0551 | generated |

#### Document Log

    2012-11-19 13:28:50,411 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,424 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,429 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,444 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d72203e81399796ef0d7108e22f89626
    2012-11-19 13:28:50,446 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,453 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,480 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,496 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:50,498 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,512 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,513 - report.md|jinja|pandoc - DEBUG - Output is cached under 29996ad27404cf4801ddb34257031d71, reconstituting...
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Output is not cached under d72203e81399796ef0d7108e22f89626, running...
    2012-11-19 13:28:50,553 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.html' in 'artifacts/d72203e81399796ef0d7108e22f89626/'
    2012-11-19 13:28:50,603 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:50,604 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:50,612 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,613 - report.md|jinja|pandoc - DEBUG - Output is cached under 374dafaaec8b9be60e3a3b94ce9df20c, reconstituting...
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Output is cached under c92599097f2fed1fc118e48ed95e0bd0, reconstituting...

## report.md|jinja|pandoc|-pdf ↑

#### Arguments

    pandoc:
        ext: .pdf

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0001 |  |
report.md|jinja | artifacts/999ed730dae84c7227d1fd380e280f57.md | 0.0021 | cached |
report.md|jinja|pandoc | artifacts/374dafaaec8b9be60e3a3b94ce9df20c.pdf | 0.0019 | cached |
report.md|jinja|pandoc|-pdf | artifacts/366f465f37a9d65c0bee00cd76d061df.pdf | 0.0006 | cached |

#### Document Log

    2012-11-19 13:28:50,408 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,411 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:50,411 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,411 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,424 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,426 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,427 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 5827f92eeba9814fbb4d56feb048b948
    2012-11-19 13:28:50,428 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,429 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,444 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d72203e81399796ef0d7108e22f89626
    2012-11-19 13:28:50,446 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,449 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,451 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:50,452 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,453 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,471 - report.md|jinja|pandoc|-pdf - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-pdf
    2012-11-19 13:28:50,473 - report.md|jinja|pandoc|-pdf - DEBUG - Setting hashstring for report.md|jinja|pandoc|-pdf to 366f465f37a9d65c0bee00cd76d061df
    2012-11-19 13:28:50,473 - report.md|jinja|pandoc|-pdf - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,476 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,478 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:50,479 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,480 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,496 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:50,498 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,511 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,512 - report.md|jinja - DEBUG - Output is cached under 2a72b42ef21c8c1f4e0febeec01055a0, reconstituting...
    2012-11-19 13:28:50,512 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,513 - report.md|jinja|pandoc - DEBUG - Output is cached under 29996ad27404cf4801ddb34257031d71, reconstituting...
    2012-11-19 13:28:50,514 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,514 - report.md|jinja - DEBUG - Output is not cached under 5827f92eeba9814fbb4d56feb048b948, running...
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/5827f92eeba9814fbb4d56feb048b948/, artifacts/5827f92eeba9814fbb4d56feb048b948
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:50,545 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:50,545 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', u'/example.txt', u'/plot.png', u'/storage.json', 'example.R-rout.txt', 'example.R|rout', u'example.txt', u'plot.png', u'storage.json']
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:50,547 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:50,550 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Output is not cached under d72203e81399796ef0d7108e22f89626, running...
    2012-11-19 13:28:50,553 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.html' in 'artifacts/d72203e81399796ef0d7108e22f89626/'
    2012-11-19 13:28:50,603 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:50,604 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:50,609 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,610 - report.md|jinja - DEBUG - Output is cached under 999ed730dae84c7227d1fd380e280f57, reconstituting...
    2012-11-19 13:28:50,612 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,613 - report.md|jinja|pandoc - DEBUG - Output is cached under 374dafaaec8b9be60e3a3b94ce9df20c, reconstituting...
    2012-11-19 13:28:50,614 - report.md|jinja|pandoc|-pdf - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-pdf
    2012-11-19 13:28:50,615 - report.md|jinja|pandoc|-pdf - DEBUG - Output is cached under 366f465f37a9d65c0bee00cd76d061df, reconstituting...
    2012-11-19 13:28:50,615 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,616 - report.md|jinja - DEBUG - Output is cached under 679cc4370ea3018f8d90b3a36b8dc579, reconstituting...
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Output is cached under c92599097f2fed1fc118e48ed95e0bd0, reconstituting...

## report.md|jinja|pandoc|-docx ↑

#### Arguments

    pandoc:
        ext: .docx
        args: --toc

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |
report.md|jinja | artifacts/679cc4370ea3018f8d90b3a36b8dc579.md | 0.0005 | cached |
report.md|jinja|pandoc | artifacts/c92599097f2fed1fc118e48ed95e0bd0.docx | 0.0005 | cached |
report.md|jinja|pandoc|-docx | artifacts/d402fc4af60607659294398faf602078.docx | 0.0003 | cached |

#### Document Log

    2012-11-19 13:28:50,408 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,411 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 2a72b42ef21c8c1f4e0febeec01055a0
    2012-11-19 13:28:50,411 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,411 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,424 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 29996ad27404cf4801ddb34257031d71
    2012-11-19 13:28:50,425 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,426 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,427 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 5827f92eeba9814fbb4d56feb048b948
    2012-11-19 13:28:50,428 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,429 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,444 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to d72203e81399796ef0d7108e22f89626
    2012-11-19 13:28:50,446 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,449 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,451 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 999ed730dae84c7227d1fd380e280f57
    2012-11-19 13:28:50,452 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,453 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 374dafaaec8b9be60e3a3b94ce9df20c
    2012-11-19 13:28:50,470 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,476 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,478 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 679cc4370ea3018f8d90b3a36b8dc579
    2012-11-19 13:28:50,479 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,480 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,496 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to c92599097f2fed1fc118e48ed95e0bd0
    2012-11-19 13:28:50,498 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,499 - report.md|jinja|pandoc|-docx - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-docx
    2012-11-19 13:28:50,501 - report.md|jinja|pandoc|-docx - DEBUG - Setting hashstring for report.md|jinja|pandoc|-docx to d402fc4af60607659294398faf602078
    2012-11-19 13:28:50,501 - report.md|jinja|pandoc|-docx - DEBUG - setting up output data of class GenericData
    2012-11-19 13:28:50,511 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,512 - report.md|jinja - DEBUG - Output is cached under 2a72b42ef21c8c1f4e0febeec01055a0, reconstituting...
    2012-11-19 13:28:50,512 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,513 - report.md|jinja|pandoc - DEBUG - Output is cached under 29996ad27404cf4801ddb34257031d71, reconstituting...
    2012-11-19 13:28:50,514 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,514 - report.md|jinja - DEBUG - Output is not cached under 5827f92eeba9814fbb4d56feb048b948, running...
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/5827f92eeba9814fbb4d56feb048b948/, artifacts/5827f92eeba9814fbb4d56feb048b948
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 13:28:50,516 - report.md|jinja - DEBUG - initializing template
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 13:28:50,517 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 13:28:50,518 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 13:28:50,545 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 13:28:50,545 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - relative refs are ['/example.R-rout.txt', '/example.R|rout', u'/example.txt', u'/plot.png', u'/storage.json', 'example.R-rout.txt', 'example.R|rout', u'example.txt', u'plot.png', u'storage.json']
    2012-11-19 13:28:50,546 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 13:28:50,547 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-19 13:28:50,550 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,551 - report.md|jinja|pandoc - DEBUG - Output is not cached under d72203e81399796ef0d7108e22f89626, running...
    2012-11-19 13:28:50,553 - report.md|jinja|pandoc - DEBUG - About to run 'pandoc --toc report.md -o report.html' in 'artifacts/d72203e81399796ef0d7108e22f89626/'
    2012-11-19 13:28:50,603 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-19 13:28:50,604 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-19 13:28:50,609 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,610 - report.md|jinja - DEBUG - Output is cached under 999ed730dae84c7227d1fd380e280f57, reconstituting...
    2012-11-19 13:28:50,612 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,613 - report.md|jinja|pandoc - DEBUG - Output is cached under 374dafaaec8b9be60e3a3b94ce9df20c, reconstituting...
    2012-11-19 13:28:50,615 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja
    2012-11-19 13:28:50,616 - report.md|jinja - DEBUG - Output is cached under 679cc4370ea3018f8d90b3a36b8dc579, reconstituting...
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc
    2012-11-19 13:28:50,616 - report.md|jinja|pandoc - DEBUG - Output is cached under c92599097f2fed1fc118e48ed95e0bd0, reconstituting...
    2012-11-19 13:28:50,617 - report.md|jinja|pandoc|-docx - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-docx
    2012-11-19 13:28:50,617 - report.md|jinja|pandoc|-docx - DEBUG - Output is cached under d402fc4af60607659294398faf602078, reconstituting...

## example.txt ↑

#### Arguments

    data-class-alias: generic
    contentshash: 8d6e60b92afeccea5db97d109b0f9324

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
example.txt | artifacts/67ca147287010eee7af5529b040a79ab.txt | 0.0000 |  |

#### Document Log

    2012-11-19 13:28:50,507 - example.txt - DEBUG - Setting up InitialVirtualArtifact:example.txt
    2012-11-19 13:28:50,507 - example.txt - DEBUG - Setting hashstring for example.txt to 67ca147287010eee7af5529b040a79ab
    2012-11-19 13:28:50,507 - example.txt - DEBUG - setting up output data of class GenericData

## plot.png ↑

#### Arguments

    data-class-alias: generic
    contentshash: 2ee9984a1b417d3f3913457f092fa0c9

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
plot.png | artifacts/a4249c9911b3be397dc5ab29237545fe.png | 0.0000 |  |

#### Document Log

    2012-11-19 13:28:50,508 - plot.png - DEBUG - Setting up InitialVirtualArtifact:plot.png
    2012-11-19 13:28:50,508 - plot.png - DEBUG - Setting hashstring for plot.png to a4249c9911b3be397dc5ab29237545fe
    2012-11-19 13:28:50,509 - plot.png - DEBUG - setting up output data of class GenericData

## storage.json ↑

#### Arguments

    data-class-alias: generic
    contentshash: e52c90460aff72033247174b30b78fec

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
storage.json | artifacts/6248a02508321609e66ae3d947f25aaa.json | 0.0000 |  |

#### Document Log

    2012-11-19 13:28:50,509 - storage.json - DEBUG - Setting up InitialVirtualArtifact:storage.json
    2012-11-19 13:28:50,510 - storage.json - DEBUG - Setting hashstring for storage.json to 6248a02508321609e66ae3d947f25aaa
    2012-11-19 13:28:50,510 - storage.json - DEBUG - setting up output data of class GenericData